blueprint-anvil-testing-utils 0.2.0-alpha.12

Anvil testing utilities for Tangle Blueprints
docs.rs failed to build blueprint-anvil-testing-utils-0.2.0-alpha.12
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: blueprint-anvil-testing-utils-0.2.0-alpha.10

blueprint-anvil-testing-utils

Anvil-focused test harness utilities.

What it includes

  • Local Anvil environment bootstrapping.
  • Blueprint test helpers on top of Anvil.
  • Multi-instance and Tangle-specific test wiring modules.

Related links